import cv2
import numpy

from flipdisc import util


def load_image(filename, area_size, binarize=0, padding=0):
    img = cv2.imread(filename)
    if img is None:
        return

    gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
    if padding:
        gray = util.pad(gray, padding)

    # Resize if needed.
    resize = max(gray.shape) > min(area_size)
    if resize:
        gray = util.resize(gray, area_size)

    # Binarize.
    if binarize is not None:
        if binarize >= 0:
            gray[gray <= binarize] = 0
            gray[gray > binarize] = 255
        else:
            # Use otsu.
            gray = cv2.threshold(gray, 0, 255, cv2.THRESH_BINARY | cv2.THRESH_OTSU)[1]

    # Copy image to the center of area.
    area = numpy.zeros(area_size, numpy.uint8)
    util.copy_to_center(area, gray)

    return area



import os

from cffi import FFI

HERE = os.path.dirname(os.path.abspath(__file__))
FDL_PATH = os.getenv('FDL_INCLUDE_DIR', '/usr/local/include/fdl')
PARTICLE_H = os.path.join(FDL_PATH, 'particle.h')
if not os.path.exists(FDL_PATH):
    raise SystemExit('** ERROR: FDL_INCLUDE_DIR "%s" does not exist' % FDL_PATH)
if not os.path.exists(PARTICLE_H):
    raise SystemExit('** ERROR: FDL_INCLUDE_DIR does not contain "particle.h"')


ffibuilder = FFI()
ffibuilder.set_source('flipdisc._particle',
        '#include "fdl/particle.h"',
        libraries=['fparticle'])

raw_cdef = open(PARTICLE_H).read()
# Skip includes and other things. This assumes the first definition
# in particle.h starts with a struct.
raw_start = raw_cdef.find('struct ')
raw_end = raw_cdef.find('#ifdef __cplusplus', raw_start + 1)
ffibuilder.cdef(raw_cdef[raw_start:raw_end])

if __name__ == "__main__":
    ffibuilder.compile(verbose=True)
